@@ -14,9 +14,9 @@
 # redistribution of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 
 package require Tcl 8.0
-package require Tk 8.0
-package require Itcl 3.3
-package require Itk 3.3
+package require Tk
+package require itcl 3.3
+package require itk 3.3
 
 namespace eval ::iwidgets {
     namespace export *
